@@ -19,9 +19,9 @@
 from typing import Iterable, List, Mapping, Optional, Union
 
 from airflow.models import BaseOperator
+from airflow.providers.amazon.aws.hooks.redshift import RedshiftSQLHook
 from airflow.providers.amazon.aws.hooks.s3 import S3Hook
 from airflow.providers.amazon.aws.utils.redshift import build_credentials_block
-from airflow.providers.postgres.hooks.postgres import PostgresHook
 
 
 class RedshiftToS3Operator(BaseOperator):
@@ -130,17 +130,23 @@ class RedshiftToS3Operator(BaseOperator):
         return f"""
                     UNLOAD ('{select_query}')
                     TO 's3://{self.s3_bucket}/{s3_key}'
-                    with credentials
+                    credentials
                     '{credentials_block}'
                     {unload_options};
         """
 
     def execute(self, context) -> None:
-        postgres_hook = PostgresHook(postgres_conn_id=self.redshift_conn_id)
-        s3_hook = S3Hook(aws_conn_id=self.aws_conn_id, verify=self.verify)
+        redshift_hook = RedshiftSQLHook(redshift_conn_id=self.redshift_conn_id)
+        conn = S3Hook.get_connection(conn_id=self.aws_conn_id)
+
+        credentials_block = None
+        if conn.extra_dejson.get('role_arn', False):
+            credentials_block = f"aws_iam_role={conn.extra_dejson['role_arn']}"
+        else:
+            s3_hook = S3Hook(aws_conn_id=self.aws_conn_id, verify=self.verify)
+            credentials = s3_hook.get_credentials()
+            credentials_block = build_credentials_block(credentials)
 
-        credentials = s3_hook.get_credentials()
-        credentials_block = build_credentials_block(credentials)
         unload_options = '\n\t\t\t'.join(self.unload_options)
 
         unload_query = self._build_unload_query(
@@ -148,5 +154,5 @@ class RedshiftToS3Operator(BaseOperator):
         )
 
         self.log.info('Executing UNLOAD command...')
-        postgres_hook.run(unload_query, self.autocommit, parameters=self.parameters)
+        redshift_hook.run(unload_query, self.autocommit, parameters=self.parameters)
         self.log.info("UNLOAD command complete...")
