@@ -15,12 +15,16 @@
 # specific language governing permissions and limitations
 # under the License.
 
+import warnings
 from typing import List, Optional, Union
 
+from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
+from airflow.providers.amazon.aws.hooks.redshift import RedshiftSQLHook
 from airflow.providers.amazon.aws.hooks.s3 import S3Hook
 from airflow.providers.amazon.aws.utils.redshift import build_credentials_block
-from airflow.providers.postgres.hooks.postgres import PostgresHook
+
+AVAILABLE_METHODS = ['APPEND', 'REPLACE', 'UPSERT']
 
 
 class S3ToRedshiftOperator(BaseOperator):
@@ -61,8 +65,10 @@ class S3ToRedshiftOperator(BaseOperator):
     :type column_list: List[str]
     :param copy_options: reference to a list of COPY options
     :type copy_options: list
-    :param truncate_table: whether or not to truncate the destination table before the copy
-    :type truncate_table: bool
+    :param method: Action to be performed on execution. Available ``APPEND``, ``UPSERT`` and ``REPLACE``.
+    :type method: str
+    :param upsert_keys: List of fields to use as key on upsert action
+    :type upsert_keys: List[str]
     """
 
     template_fields = ('s3_bucket', 's3_key', 'schema', 'table', 'column_list', 'copy_options')
@@ -82,9 +88,21 @@ class S3ToRedshiftOperator(BaseOperator):
         column_list: Optional[List[str]] = None,
         copy_options: Optional[List] = None,
         autocommit: bool = False,
-        truncate_table: bool = False,
+        method: str = 'APPEND',
+        upsert_keys: Optional[List[str]] = None,
         **kwargs,
     ) -> None:
+
+        if 'truncate_table' in kwargs:
+            warnings.warn(
+                """`truncate_table` is deprecated. Please use `REPLACE` method.""",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+            if kwargs['truncate_table']:
+                method = 'REPLACE'
+            kwargs.pop('truncate_table', None)
+
         super().__init__(**kwargs)
         self.schema = schema
         self.table = table
@@ -96,38 +114,62 @@ class S3ToRedshiftOperator(BaseOperator):
         self.column_list = column_list
         self.copy_options = copy_options or []
         self.autocommit = autocommit
-        self.truncate_table = truncate_table
+        self.method = method
+        self.upsert_keys = upsert_keys
 
-    def _build_copy_query(self, credentials_block: str, copy_options: str) -> str:
+        if self.method not in AVAILABLE_METHODS:
+            raise AirflowException(f'Method not found! Available methods: {AVAILABLE_METHODS}')
+
+    def _build_copy_query(self, copy_destination: str, credentials_block: str, copy_options: str) -> str:
         column_names = "(" + ", ".join(self.column_list) + ")" if self.column_list else ''
         return f"""
-                    COPY {self.schema}.{self.table} {column_names}
+                    COPY {copy_destination} {column_names}
                     FROM 's3://{self.s3_bucket}/{self.s3_key}'
-                    with credentials
+                    credentials
                     '{credentials_block}'
                     {copy_options};
         """
 
     def execute(self, context) -> None:
-        postgres_hook = PostgresHook(postgres_conn_id=self.redshift_conn_id)
-        s3_hook = S3Hook(aws_conn_id=self.aws_conn_id, verify=self.verify)
-        credentials = s3_hook.get_credentials()
-        credentials_block = build_credentials_block(credentials)
+        redshift_hook = RedshiftSQLHook(redshift_conn_id=self.redshift_conn_id)
+        conn = S3Hook.get_connection(conn_id=self.aws_conn_id)
+
+        credentials_block = None
+        if conn.extra_dejson.get('role_arn', False):
+            credentials_block = f"aws_iam_role={conn.extra_dejson['role_arn']}"
+        else:
+            s3_hook = S3Hook(aws_conn_id=self.aws_conn_id, verify=self.verify)
+            credentials = s3_hook.get_credentials()
+            credentials_block = build_credentials_block(credentials)
+
         copy_options = '\n\t\t\t'.join(self.copy_options)
+        destination = f'{self.schema}.{self.table}'
+        copy_destination = f'#{self.table}' if self.method == 'UPSERT' else destination
 
-        copy_statement = self._build_copy_query(credentials_block, copy_options)
+        copy_statement = self._build_copy_query(copy_destination, credentials_block, copy_options)
+
+        if self.method == 'REPLACE':
+            sql = ["BEGIN;", f"DELETE FROM {destination};", copy_statement, "COMMIT"]
+        elif self.method == 'UPSERT':
+            keys = self.upsert_keys or redshift_hook.get_table_primary_key(self.table, self.schema)
+            if not keys:
+                raise AirflowException(
+                    f"No primary key on {self.schema}.{self.table}. Please provide keys on 'upsert_keys'"
+                )
+            where_statement = ' AND '.join([f'{self.table}.{k} = {copy_destination}.{k}' for k in keys])
+
+            sql = [
+                f"CREATE TABLE {copy_destination} (LIKE {destination});",
+                copy_statement,
+                "BEGIN;",
+                f"DELETE FROM {destination} USING {copy_destination} WHERE {where_statement};",
+                f"INSERT INTO {destination} SELECT * FROM {copy_destination};",
+                "COMMIT",
+            ]
 
-        if self.truncate_table:
-            delete_statement = f'DELETE FROM {self.schema}.{self.table};'
-            sql = f"""
-            BEGIN;
-            {delete_statement}
-            {copy_statement}
-            COMMIT
-            """
         else:
             sql = copy_statement
 
         self.log.info('Executing COPY command...')
-        postgres_hook.run(sql, self.autocommit)
+        redshift_hook.run(sql, autocommit=self.autocommit)
         self.log.info("COPY command complete...")
